.. SciKit-Learn Laboratory documentation master file, created by
   sphinx-quickstart on Tue Jul 16 09:06:32 2013.

SciKit-Learn Laboratory (SKLL)
==============================

SKLL (pronounced "skull") provides a number of utilities to make it simpler to
run common scikit-learn experiments with pre-generated features.

There are two primary means of using SKLL: :doc:`the run_experiment script <run_experiment>`
and :doc:`the Python API <skll>`.


Documentation
=============

.. toctree::
   :maxdepth: 3

   getting_started
   run_experiment
   utilities
   skll


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

